# pysmarty2

Python API for Salda Smarty 2X/3X/4X P/V Ventilation Unit. This is used in [Home Assistant](https://home-assistant.io).

This package, `pysmarty2`, is a fork of the original [`pysmarty`](https://github.com/z0mbieprocess/pysmarty) created by [z0mbieprocess](https://github.com/z0mbieprocess).

The package was renamed to `pysmarty2` to allow for publishing it to PyPI without conflicting with the existing `pysmarty` package.


## Install

```bash
pip install pysmarty2
```

## Acknowledgments

Please give credit to the original author for their work on `pysmarty`. This fork was created to make minor modifications and improvements, but the majority of the work remains the original author's.
